import winreg, os, sys

ICON_NAME = 'play.ico'

REG_PATH_BACKGROUND = r'Software\Classes\directory\Background\shell\opensubz'
REG_PATH_FOLDER = r'Software\Classes\directory\shell\opensubz'
ICON_PATH = '"' + os.path.join(sys.prefix, 'icon', 'play.ico') + '"'
PYTHON_SCRIPT_PATH = os.path.join(os.path.abspath(os.path.dirname(sys.argv[0])), 'opensubz.exe')
SCRIPT_PATH_BACKGROUND = '"' + PYTHON_SCRIPT_PATH + '" "--search" "%V"'
SCRIPT_PATH_FOLDER = '"' + PYTHON_SCRIPT_PATH + '" "--search" "%1"'


def set_reg(name, value, reg_path):
    try:
        winreg.CreateKey(winreg.HKEY_CURRENT_USER, reg_path)
        registry_key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, reg_path, 0,
                                      winreg.KEY_WRITE)
        winreg.SetValueEx(registry_key, name, 0, winreg.REG_SZ, value)
        winreg.CloseKey(registry_key)
        return True
    except WindowsError as e:
        print(e)
        print('\nAn error occurred when trying to add the "Download Subtitles" shortcut to the context menu.')
        return False


def get_reg(name, reg_path):
    try:
        registry_key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, reg_path, 0,
                                      winreg.KEY_READ)
        value, regtype = winreg.QueryValueEx(registry_key, name)
        winreg.CloseKey(registry_key)
        return value
    except WindowsError:
        return None


def install():
    # Add keys to Registry
    set_reg('', 'Download Subtitles', REG_PATH_BACKGROUND)
    set_reg('Icon', ICON_PATH, REG_PATH_BACKGROUND)
    set_reg('', SCRIPT_PATH_BACKGROUND, REG_PATH_BACKGROUND + '\command')

    set_reg('', 'Download Subtitles', REG_PATH_FOLDER)
    set_reg('Icon', ICON_PATH, REG_PATH_FOLDER)
    set_reg('', SCRIPT_PATH_FOLDER, REG_PATH_FOLDER + '\command')

    print('\n"Download Subtitles" shortcut added to the Windows context menu.')


def uninstall():
    print('\nNot supported yet.')







import struct
import os
import hashlib
import zlib
import base64


def get_gzip_base64_encoded(file_path):
    handler = open(file_path, mode='rb').read()
    return base64.encodestring(zlib.compress(handler))


def get_md5(file_path):
    '''Return the md5 of a file.
    '''
    f = open(file_path, 'rb').read()
    return hashlib.md5(f).hexdigest()


class File(object):
    def __init__(self, path):
        self.path = path
        self.size = str(os.path.getsize(path))

    def get_hash(self):
        '''Original from: http://goo.gl/qqfM0
        '''
        longlongformat = 'q'  # long long
        bytesize = struct.calcsize(longlongformat)

        try:
            f = open(self.path, "rb")
        except(IOError):
            return "IOError"

        hash = int(self.size)

        if int(self.size) < 65536 * 2:
            return "SizeError"

        for x in range(65536 // bytesize):
            buffer = f.read(bytesize)
            (l_value, ) = struct.unpack(longlongformat, buffer)
            hash += l_value
            hash = hash & 0xFFFFFFFFFFFFFFFF  # to remain as 64bit number

        f.seek(max(0, int(self.size) - 65536), 0)
        for x in range(65536 // bytesize):
            buffer = f.read(bytesize)
            (l_value, ) = struct.unpack(longlongformat, buffer)
            hash += l_value
            hash = hash & 0xFFFFFFFFFFFFFFFF

        f.close()
        returnedhash = "%016x" % hash
        return str(returnedhash)



import configparser
import os
import sys


class Config:

    PATH = os.path.join(sys.prefix, 'config', 'opensubz.ini')
    OPENSUBTITLES = 'opensubtitles'
    EMAIL = 'email'
    PASSWORD = 'password'
    LANGUAGE = 'language'

    def __init__(self):
        self.config = configparser.ConfigParser()
        self.config.read(Config.PATH)

        self.email = self.config.get(Config.OPENSUBTITLES, Config.EMAIL)
        self.password = self.config.get(Config.OPENSUBTITLES, Config.PASSWORD)
        self.language = self.config.get(Config.OPENSUBTITLES, Config.LANGUAGE)

    def save(self):
        self.config.set(Config.OPENSUBTITLES, Config.EMAIL, self.email)
        self.config.set(Config.OPENSUBTITLES, Config.PASSWORD, self.password)
        self.config.set(Config.OPENSUBTITLES, Config.LANGUAGE, self.language)
        with open(Config.PATH, 'w') as configfile:
            self.config.write(configfile)
